@@ -1,12 +1,12 @@
 package Perinci::Result::Format::Lite;
 
-our $DATE = '2016-04-08'; # DATE
-our $VERSION = '0.14'; # VERSION
+our $DATE = '2016-06-12'; # DATE
+our $VERSION = '0.15'; # VERSION
 
 use 5.010001;
 #IFUNBUILT
-use strict;
-use warnings;
+# use strict;
+# use warnings;
 #END IFUNBUILT
 
 use List::Util qw(first);
@@ -127,12 +127,48 @@ sub __gen_table {
         my $tfu = $resmeta->{'table.field_units'} or last;
         for my $i (0..$#{$data->[0]}) {
             my $field_idx = firstidx { $_ eq $data->[0][$i] } @$tff;
-            next unless $field_idx;
+            next unless defined $field_idx;
             next unless defined $tfu->[$field_idx];
             $data->[0][$i] .= " ($tfu->[$field_idx])";
         }
     }
 
+    # format cells
+    {
+        my $tff   = $resmeta->{'table.fields'} or last;
+        my $tffmt = $resmeta->{'table.field_formats'} or last;
+
+        # load required modules
+        for my $ffmt (@$tffmt) {
+            if ($ffmt eq 'iso8601') {
+                #require Time::Local;
+            }
+        }
+
+        for my $i (0..$#{$data}) {
+            my $row = $data->[$i];
+            for my $j (0..$#{$row}) {
+                next unless defined $row->[$j];
+                my $ffmt = $tffmt->[$j];
+                next unless $ffmt;
+                if ($ffmt eq 'iso8601_datetime' || $ffmt eq 'iso8601_date') {
+                    if ($row->[$j] =~ /\A[0-9]+\z/) {
+                        my @t = gmtime($row->[$j]);
+                        if ($ffmt eq 'iso8601_datetime') {
+                            $row->[$j] = sprintf(
+                                "%04d-%02d-%02dT%02d:%02d:%02dZ",
+                                $t[5]+1900, $t[4]+1, $t[3], $t[2], $t[1], $t[0]);
+                        } else {
+                            $row->[$j] = sprintf(
+                                "%04d-%02d-%02d",
+                                $t[5]+1900, $t[4]+1, $t[3]);
+                        }
+                    }
+                }
+            }
+        }
+    }
+
     if ($format eq 'text-pretty') {
         require Text::Table::Tiny;
         Text::Table::Tiny::table(rows=>$data, header_row=>$header_row) . "\n";
@@ -255,7 +291,7 @@ Perinci::Result::Format::Lite - Format enveloped result
 
 =head1 VERSION
 
-This document describes version 0.14 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2016-04-08.
+This document describes version 0.15 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2016-06-12.
 
 =head1 SYNOPSIS
 
